#!/bin/sh
# Make the necessary changes to language packs from Mozilla, so they work on GnuZilla
# Version 2013.01.13
# Copyright (GNU GPL) Narcis Garcia

VersionToWork="$1"
ExportsBasePath="."
FirstUrlPart="ftp://ftp.mozilla.org/pub/firefox/releases/"
SecondUrlPart="/linux-i686/xpi/"

##### SPECIFIC FUNCTIONS TO THIS SCRIPT #####

ReplaceFileString ()
{
	local TheFile="$1"
	local OldString="$2"
	local NewString="$3"
	local TempFile=""
	
	TempFile="$(mktemp)"
	cat "$TheFile" | sed -e "s/$OldString/$NewString/g" > "$TempFile"
	cat "$TempFile" > "$TheFile"
	rm "$TempFile"
}

##### MAIN SCRIPT #####

Result=0
ResultN=0

if [ "$VersionToWork" != "" ] ; then
	PreviousDir="$(pwd)"
	cd "$ExportsBasePath"
	ExportsDir="$(pwd)"
	if [ ! -d "${ExportsDir}/${VersionToWork}" ] || [ -f "${ExportsDir}/$VersionToWork/error.log" ] ; then
		if [ -f "${ExportsDir}/$VersionToWork/error.log" ] ; then
			echo "Going to redo a conversion for $VersionToWork"
		fi
		rm -rf "${ExportsDir}/${VersionToWork}"
		TempDir="$(mktemp -d)"
		mkdir -p "${TempDir}/mozilla"
		mkdir -p "${TempDir}/currentconversion"
		mkdir -p "${TempDir}/gnuzilla"
		cd "${TempDir}/mozilla"
		if [ "$(echo "$FirstUrlPart" | grep -e '/$')" = "" ] ; then
			FirstUrlPart="${FirstUrlPart}/"
		fi
		if [ "$(echo "$SecondUrlPart" | grep -e '^/')" = "" ] ; then
			SecondUrlPart="/${SecondUrlPart}"
		fi
		if [ "$(echo "$SecondUrlPart" | grep -e '/$')" = "" ] ; then
			SecondUrlPart="${SecondUrlPart}/"
		fi
		echo "Downloading Mozilla packages..."
		wget --recursive --level=1 --no-directories --no-parent --no-verbose '--accept=*.xpi' "${FirstUrlPart}${VersionToWork}${SecondUrlPart}*"
		Result=$? ; if [ $ResultN -eq 0 ] ; then ResultN=$Result ; fi
		mkdir -p "${ExportsDir}/${VersionToWork}"
		if [ $ResultN -eq 0 ] ; then
			PackagesToConvert="$(ls -1 *.xpi)"
			IFS="$(printf "\n\b")" ; for CurrentPackage in $PackagesToConvert ; do unset IFS
				CurrentResult=0
				echo "Converting $CurrentPackage"
				cd "${TempDir}/currentconversion"
				unzip -q "$TempDir/mozilla/$CurrentPackage"
				Result=$? ; if [ $ResultN -eq 0 ] ; then ResultN=$Result ; fi
				if [ $CurrentResult -eq 0 ] ; then CurrentResult=$Result ; fi
				CurrentSearch="$(find -type f)"
				IFS="$(printf "\n\b")" ; for CurrentFile in $CurrentSearch ; do unset IFS
					if [ "$(echo "$CurrentFile" | grep -ie '/install.rdf')" = "" ] ; then
						ReplaceFileString "$CurrentFile" "www.mozilla.org" "gnuzilla.gnu.org"
						ReplaceFileString "$CurrentFile" "Mozilla Firefox" "GNU IceCat"
						ReplaceFileString "$CurrentFile" "Mozilla" "GNUzilla"
						ReplaceFileString "$CurrentFile" "Firefox" "IceCat"
					fi
				done
				zip -q -r "$TempDir/gnuzilla/$CurrentPackage" .
				Result=$? ; if [ $ResultN -eq 0 ] ; then ResultN=$Result ; fi
				if [ $CurrentResult -eq 0 ] ; then CurrentResult=$Result ; fi
				rm -fr "${TempDir}/currentconversion/"*
				if [ $CurrentResult -eq 0 ] ; then
					mv "$TempDir/gnuzilla/$CurrentPackage" "$ExportsDir/$VersionToWork/"
					Result=$? ; if [ $ResultN -eq 0 ] ; then ResultN=$Result ; fi
					if [ $CurrentResult -eq 0 ] ; then CurrentResult=$Result ; fi
				fi
				if [ $CurrentResult -ne 0 ] ; then
					echo "ERROR: Package $CurrentPackage failed."
				fi
			done
		fi
		if [ $ResultN -eq 0 ] ; then
			rm -fr "${TempDir}"
		else
			echo "Last process ended with error $ResultN" > "${ExportsDir}/${VersionToWork}/error.log"
		fi
	else
		Result=1 ; if [ $ResultN -eq 0 ] ; then ResultN=$Result ; fi
		echo "ERROR: The directory $VersionToWork already exists."
		echo "       Conversion may be already done for this version."
	fi
	cd "$PreviousDir"
else
	Result=1 ; if [ $ResultN -eq 0 ] ; then ResultN=$Result ; fi
	echo 'ERROR: You must specify the Mozilla/GnuZilla version.'
fi
exit $ResultN
